/**
 *--------------------------------------------------------------------\n
 *          HSLU T&A Hochschule Luzern Technik+Architektur            \n
 *--------------------------------------------------------------------\n
 *
 * \brief         A/D converter driver
 * \file
 * \author        Christian Jost, christian.jost@hslu.ch
 * \date          26.11.2012
 *
 * \b Language:   Ansi-C \n\n
 * \b Target:     MC-Car  \n
 *
 * \par Description:
 *
 * $Id: adc.c 377 2012-11-26 15:18:07Z zajost $
 *--------------------------------------------------------------------
 */
#include "platform.h"
#include "adc.h"


#define ADC_RES_8BIT      0
#define ADC_RES_10BIT     2
#define ADC_RES_12BIT     1


/**
 * Performs one A/D conversion for the specified channel
 * with 12 bit resolution. The function blocks until the
 * conversion has been finished. 
 */
uint16 adcGet12BitValue(AdcChannels ch)
{
  ADCCFG_MODE = ADC_RES_12BIT;  // set resolution
  ADCSC1_ADCH = (uint8)ch;      // start new conversion
  while(!ADCSC1_COCO);          // wait until conversion has completed
  return ADCR;
}

/**
 * Performs one A/D conversion for the specified channel
 * with 10 bit resolution. The function blocks until the
 * conversion has been finished. 
 */
uint16 adcGet10BitValue(AdcChannels ch)
{
  ADCCFG_MODE = ADC_RES_10BIT;  // set resolution
  ADCSC1_ADCH = (uint8)ch;      // start new conversion
  while(!ADCSC1_COCO);          // wait until conversion has completed
  return ADCR;
}

/**
 * Performs one A/D conversion for the specified channel
 * with 8 bit resolution. The function blocks until the
 * conversion has been finished. 
 */
uint8 adcGet8BitValue(AdcChannels ch)
{
  ADCCFG_MODE = ADC_RES_8BIT;   // set resolution
  ADCSC1_ADCH = (uint8)ch;      // start new conversion
  while(!ADCSC1_COCO);          // wait until conversion has completed
  return ADCRL;
}


/**
 * Configures the A/D converter as follows:
 * - high speed mode with long sample time
 * - set ADCK = 6 MHz (bus clock / 4)
 * - enables the four line sensors
 */
void adcInit(void)
{
  // max conversion time: 40x ADCK cycles + 5 bus clock cycles
  // 40x 167ns + 5x 42ns = 7.21us
  // long sample time for higher conversion accuracy
  ADCCFG_ADLPC = 0;       // high speed
  ADCCFG_ADLSMP = 1;      // long sample time
  ADCCFG_ADICLK = 0;      // bus clock = 24 MHz
  
  APCTL1 = 0xF0;          // LsL, LsML. LsMR, LsR
    
  // valid clock: 0.4 - 4 MHz if ADLPC = 1
  ADCCFG_ADIV = 2;        // 0=/1,  1=/2,  2=/4, 3=/8
}